@@ -44,14 +44,7 @@ def extract(field, grad=True, sym=False, add_identity=True):
 def values(field):
     "Return values of a field or a tuple of fields."
 
-    if "mixed" in str(type(field)).lower():
-        field = field.fields
-
-    if isinstance(field, tuple) or isinstance(field, list):
-        return np.concatenate([f.values.ravel() for f in field])
-
-    else:
-        return field.values.ravel()
+    return np.concatenate([f.values.ravel() for f in field.fields])
 
 
 def norm(array):
